@@ -30,6 +30,7 @@ export const DRAFT_TIMESIGH_STORAGE_KEY = '|_a_t_s_|';
 export const QUESTIONS_ORDER_STORAGE_KEY = '_a_qok_';
 export const DEFAULT_THEME = 'system';
 export const ADMIN_PRIVILEGE_CUSTOM_LEVEL = 99;
+export const SKELETON_SHOW_TIME = 1000;
 
 export const USER_AGENT_NAMES = {
   SegmentFault: 'SegmentFault',
@@ -54,6 +55,11 @@ export const ADMIN_LIST_STATUS = {
     variant: 'text-bg-danger',
     name: 'deleted',
   },
+  // pending
+  11: {
+    variant: 'text-bg-warning',
+    name: 'pending',
+  },
   normal: {
     variant: 'text-bg-success',
     name: 'normal',
@@ -66,6 +72,14 @@ export const ADMIN_LIST_STATUS = {
     variant: 'text-bg-danger',
     name: 'deleted',
   },
+  pending: {
+    variant: 'text-bg-warning',
+    name: 'pending',
+  },
+  unlisted: {
+    variant: 'text-bg-secondary',
+    name: 'unlisted',
+  },
 };
 
 export const ADMIN_NAV_MENUS = [
@@ -80,10 +94,6 @@ export const ADMIN_NAV_MENUS = [
   {
     name: 'users',
   },
-  {
-    name: 'flags',
-    // badgeContent: 5,
-  },
   {
     name: 'customize',
     children: [
